@@ -6,12 +6,19 @@ class ProtocolJSONEncoder(json.JSONEncoder):
 
     def default(self, obj):
         import classbuilder
+
+        if isinstance(obj, classbuilder.LiteralValue):
+            return obj._value
         if isinstance(obj, classbuilder.ProtocolBase):
             props = {}
             for raw, trans in obj.__prop_names__.iteritems():
                 props[raw] = getattr(obj, trans)
                 if props[raw] is None:
                     del props[raw]
+            for raw, data in obj._extended_properties.iteritems():
+                props[raw] = data
+                if props[raw] is None:
+                    del props[raw]
             return props
         else:
             return json.JSONEncoder.default(self, obj)
